@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::Sah::Schemas;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-20'; # DATE
+our $DATE = '2021-07-22'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.066'; # VERSION
+our $VERSION = '0.067'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -83,8 +83,8 @@ sub weave_section {
             {
                 # XXX don't add if current See Also already mentions it
                 my @pod = (
-                    "L<Sah> - specification\n\n",
-                    "L<Data::Sah>\n\n",
+                    "L<Sah> - schema specification\n\n",
+                    "L<Data::Sah> - Perl implementation of Sah\n\n",
                 );
                 $self->add_text_to_section(
                     $document, join('', @pod), 'SEE ALSO',
@@ -160,7 +160,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -249,7 +249,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.066 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2021-07-20.
+This document describes version 0.067 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2021-07-22.
 
 =head1 SYNOPSIS
 
